@@ -1,11 +1,11 @@
 #############################################################################
-## Name:        ext/calendar/Calendar.pm
+## Name:        Calendar.pm
 ## Purpose:     Wx::CalendarCtrl
 ## Author:      Mattia Barbon
 ## Modified by:
-## Created:     05/10/2002
-## RCS-ID:      $Id: Calendar.pm,v 1.7.2.1 2005/08/15 16:17:10 mbarbon Exp $
-## Copyright:   (c) 2002, 2005 Mattia Barbon
+## Created:      5/10/2002
+## RCS-ID:      
+## Copyright:   (c) 2002 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
 #############################################################################
@@ -27,10 +27,8 @@ Wx::wx_boot( 'Wx::Calendar', $VERSION );
 
 no strict;
 
-package Wx::CalendarCtrl;    @ISA = 'Wx::Control';
-package Wx::DatePickerCtrl;  @ISA = 'Wx::Control';
-package Wx::DateEvent;       @ISA = 'Wx::CommandEvent';
-package Wx::CalendarEvent;   @ISA = 'Wx::DateEvent';
+package Wx::CalendarCtrl;  @ISA = 'Wx::Control';
+package Wx::CalendarEvent; @ISA = 'Wx::CommandEvent';
 
 package Wx::Event;
 
@@ -45,7 +43,6 @@ sub EVT_CALENDAR_DAY($$$) { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_CALENDAR_DAY_C
 sub EVT_CALENDAR_MONTH($$$) { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_CALENDAR_MONTH_CHANGED, $_[2] ) }
 sub EVT_CALENDAR_YEAR($$$) { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_CALENDAR_YEAR_CHANGED, $_[2] ) }
 sub EVT_CALENDAR_WEEKDAY_CLICKED($$$) { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_CALENDAR_WEEKDAY_CLICKED, $_[2] ) }
-sub EVT_DATE_CHANGED($$$) { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_DATE_CHANGED, $_[2] ) }
 
 1;
 
